==> gramps-3.1.3.tgz: share/gramps/Filters/Rules/Note/_MatchesSubstringOf.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2002-2006  Donald N. Allingham
# Copyright (C) 2008       Brian G. Matherly
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

# $Id: _MatchesSubstringOf.py 10326 2008-03-15 21:10:30Z pez4brian $

#-------------------------------------------------------------------------
#
# Standard Python modules
#
#-------------------------------------------------------------------------
from gettext import gettext as _

#-------------------------------------------------------------------------
#
# GRAMPS modules
#
#-------------------------------------------------------------------------
from Filters.Rules import Rule

#-------------------------------------------------------------------------
# "Events having notes that contain a substring"
#-------------------------------------------------------------------------
class MatchesSubstringOf(Rule):
    """Notes having notes containing <subtring>"""

    labels      = [ _('Substring:')]
    name        = _('Notes containing <substring>')
    description = _("Matches notes who contain text "
                    "matching a substring")
    category    = _('General filters')

    def apply(self, db, note):
        """ Apply the filter """
        text = unicode(note.get())
        if text.upper().find(self.list[0].upper()) != -1:
            return True
        return False

==> gramps-3.2.5.tgz: share/gramps/Filters/Rules/Note/_MatchesSubstringOf.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2002-2006  Donald N. Allingham
# Copyright (C) 2008       Brian G. Matherly
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

# $Id: _MatchesSubstringOf.py 15596 2010-06-28 07:28:16Z ldnp $

#-------------------------------------------------------------------------
#
# Standard Python modules
#
#-------------------------------------------------------------------------
from gen.ggettext import gettext as _

#-------------------------------------------------------------------------
#
# GRAMPS modules
#
#-------------------------------------------------------------------------
from Filters.Rules import Rule

#-------------------------------------------------------------------------
# "Events having notes that contain a substring"
#-------------------------------------------------------------------------
class MatchesSubstringOf(Rule):
    """Notes having notes containing <subtring>"""

    labels      = [ _('Substring:')]
    name        = _('Notes containing <substring>')
    description = _("Matches notes who contain text "
                    "matching a substring")
    category    = _('General filters')

    def apply(self, db, note):
        """ Apply the filter """
        text = note.get()
        if text.upper().find(self.list[0].upper()) != -1:
            return True
        return False
